@@ -1,4 +1,4 @@
 """Face detection."""
 from .cascade import HAARCascade as HAARFaceDetector
 from .cascade import LBPCascade as LBPFaceDetector
-from .ssd_quantized import SSD as SSDFaceDetector
\ No newline at end of file
+from .ssd import SSDFaceDetector
\ No newline at end of file
